- fap0
nominal false Alarm Probabilty in Phase 1
- interval
searching range of charting constants for the exact method
- m
number of observations
- order
order for ARMA(p, q) model
- phi.vec
a vector of length p containing autoregressive coefficient(s). When case = 'K', the vector must have a length equal to the first value in the order. If no autoregressive coefficent presents, set phi.vec = NULL
- theta.vec
a vector of length q containing moving-average coefficient(s). When case = 'K', the vector must have a length equal to the first value in the order. If no moving-average coefficent presents, set theta.vec = NULL
- case
known or unknown case. When case = 'U', the parameters are estimated, when case = 'K', the parameters need to be input
- method
estimation method for the control chart. When method = 'Method 3' is maximum likehood estimations plus method of moments. Other options are 'Method 1' which is pure MLE and 'Method 2' which is pure CSS.
- nsim.coefs
number of simulation for coeficients. It is functional when double.sim = TRUE.
- nsim.process
number of simulation for ARMA processes
- burn.in
number of burn-ins. When burn.in = 0, the ECM gets involved. When burn.in is large enough, the ACM gets involved.
- sim.type
type of simulation. When sim.type = 'Matrix', the simulation is generated using matrix computation. When sim.type = 'Recursive', the simulation is based on a recursion.
- verbose
print diagnostic information about fap0 and the charting constant during the simulations for the exact method